@@ -12,31 +12,57 @@ from .exception_handling import handling_exceptions
 from .exceptions import NoActiveSession, SkipTest, TestFailed
 from .metadata import ensure_test_metadata
 from .test_context import get_test_context_setup
-from .utils.peekable_iterator import PeekableIterator
+from .utils.iteration import PeekableIterator
 
 _logger = logbook.Logger(__name__)
 
-def run_tests(iterable):
+def run_tests(iterable, stop_on_error=None):
     """
     Runs tests from an iterable using the current session
     """
+    #pylint: disable=maybe-no-member
     if context.session is None:
         raise NoActiveSession("A session is not currently active")
+
+    if stop_on_error is None:
+        stop_on_error = config.root.run.stop_on_error
+
     test_iterator = PeekableIterator(iterable)
+    last_filename = None
+    complete = False
     for test in test_iterator:
         ensure_test_metadata(test)
+        test_filename = test.__slash__.fqn.path
+        if last_filename != test_filename:
+            context.session.reporter.report_file_start(test_filename)
+            last_filename = test_filename
+        context.session.reporter.report_test_start(test)
         _logger.debug("Running {0}...", test)
         with _get_run_context_stack(test, test_iterator):
             test.run()
         result = context.session.results[test]
+        context.session.reporter.report_test_end(test, result)
+        if not test_iterator.has_next() or ensure_test_metadata(test_iterator.peek()).fqn.path != last_filename:
+            context.session.reporter.report_file_end(last_filename)
         if result.has_fatal_exception():
             _logger.debug("Stopping on fatal exception")
             break
-        if not result.is_success() and not result.is_skip() and config.root.run.stop_on_error:
+        if not result.is_success() and not result.is_skip() and stop_on_error:
             _logger.debug("Stopping (run.stop_on_error==True)")
             break
     else:
+        complete = True
+
+    _mark_remaining_skipped(test_iterator)
+    if complete:
         context.session.mark_complete()
+    elif last_filename is not None:
+        context.session.reporter.report_file_end(last_filename)
+
+def _mark_remaining_skipped(test_iterator):
+    for test in test_iterator:
+        with _get_test_context(test):
+            context.session.results.create_result(test).add_skip("Did not run")
 
 @contextmanager
 def _get_run_context_stack(test, test_iterator):
@@ -81,25 +107,25 @@ def _get_test_context(test):
 
 @contextmanager
 def _get_test_hooks_context():
-    hooks.test_start()
+    hooks.test_start()  # pylint: disable=no-member
     try:
         yield
     except SkipTest as skip_exception:
-        hooks.test_skip(reason=skip_exception.reason)
+        hooks.test_skip(reason=skip_exception.reason)  # pylint: disable=no-member
     except TestFailed:
-        hooks.test_failure()
+        hooks.test_failure()  # pylint: disable=no-member
     except KeyboardInterrupt:
-        hooks.test_interrupt()
+        hooks.test_interrupt()  # pylint: disable=no-member
         raise
     except:
-        hooks.test_error()
+        hooks.test_error()  # pylint: disable=no-member
     else:
         if context.session.results.get_result(context.test).is_success_finished():
-            hooks.test_success()
+            hooks.test_success()  # pylint: disable=no-member
         else:
-            hooks.test_error()
+            hooks.test_error()  # pylint: disable=no-member
     finally:
-        hooks.test_end()
+        hooks.test_end()  # pylint: disable=no-member
 
 @contextmanager
 def _set_current_test_context(test):
@@ -116,6 +142,7 @@ def _set_current_test_context(test):
 @contextmanager
 def _update_result_context():
     result = context.session.results.create_result(context.test)
+    result.mark_started()
     try:
         try:
             yield result
